@@ -4,9 +4,10 @@ DISTRIB="$1"
 TDE_VERSION="$2"
 ARCH="$3"
 
-[ -z "${TDE_VERSION}" ] && TDE_VERSION="14.1.1"
+[ -z "${TDE_VERSION}" ] && TDE_VERSION="14.1.2"
 [ -z "${ARCH}" ] && ARCH="x86_64"
 [ -x /usr/bin/podman ] && DOCKER=podman || DOCKER=docker
+[ -x /usr/bin/pigz ] && GZIP=pigz || GZIP=gzip
 
 IMAGE="trinity.${DISTRIB}.${ARCH}:${TDE_VERSION}"
 FILE="${HOME}/tde/docker/${IMAGE}.tar.gz"
@@ -20,11 +21,11 @@ else
   echo "Building new Docker image '${IMAGE}'."
   ${DOCKER} build -t "${IMAGE}" -f "${DISTRIB}/Dockerfile.${ARCH}" --build-arg TDE_VERSION="${TDE_VERSION}" --build-arg ARCH="${ARCH}" "${DISTRIB}"
   echo "Saving image to '${FILE}'"
-  ${DOCKER} image save "${IMAGE}" | pigz >"${FILE}"
+  ${DOCKER} image save "${IMAGE}" | ${GZIP} >"${FILE}"
 fi
 
 # Strip 'localhost/' prefix from image tag
-if ! docker images | while read name tag blah; do echo "${name}:${tag}"; done | grep -q "^${IMAGE}$"; then
-  docker image tag "localhost/${IMAGE}" "${IMAGE}"
-  #docker image remove "localhost/${IMAGE}"
+if ! ${DOCKER} images | while read name tag blah; do echo "${name}:${tag}"; done | grep -q "^${IMAGE}$"; then
+  ${DOCKER} image tag "localhost/${IMAGE}" "${IMAGE}"
+  #${DOCKER} image remove "localhost/${IMAGE}"
 fi
